<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Mega Blog Pro
 * @since Mega Blog Pro 1.0.0
 * @return array An array of default values
 */

function mega_blog_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$mega_blog_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'brown',
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'mega-blog-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'mega-blog-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'mega-blog-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Message,Featured,Recent,Gallery,Popular',

		// custom header
		'custom_header_blog' 			=> true,
		'custom_header_title' 			=> esc_html__( 'Beautiful Grey Sofa', 'mega-blog-pro' ),
		'custom_header_sub_title' 		=> esc_html__( 'Living Room', 'mega-blog-pro' ),

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'mega-blog-pro' ),
		'hide_date' 					=> false,
		'hide_author'					=> false,
		'hide_category'					=> false,
		'hide_tags'						=> false,
		'hide_comments'					=> false,
		'header_text_background_opacity' => 80,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */
		// Top bar
		'topbar_section_enable'			=> true,
		'topbar_social_enable'			=> true,
		'topbar_menu_enable'			=> true,

		// Message
		'message_section_enable'		=> true,
		'message_content_type'			=> 'custom',
		'message_title'					=> esc_html__( 'Hello, I&#39;m August Parker', 'mega-blog-pro' ),
		'message_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Cras et urna at nisi convallis pulvinar. Aliquam a lacus convallis, pretium felis a, tempor magna. Donec interdum commodo turpis et vestibulum. Vestibulum tincidunt ex efficitur dapibus suscipit. Maecenas lacinia vitae augue ut blandit. Nulla nec ex vitae nisi accumsan ullamcorper vel sit amet ex.', 'mega-blog-pro' ),
		'message_image'					=> get_template_directory_uri() . '/assets/uploads/augustus-parker.jpg',
		'message_social'				=> 'http://facebook.com|http://twitter.com|http://instagram.com',

		// Featured
		'featured_section_enable'		=> true,
		'featured_title'				=> esc_html__( 'Featured Posts', 'mega-blog-pro' ),
		'featured_content_type'			=> 'recent',
		'featured_column'				=> 'col-3',
		'featured_count'				=> 3,

		// Recent
		'recent_section_enable'			=> true,
		'recent_title'					=> esc_html__( 'Recent Posts', 'mega-blog-pro' ),
		'recent_content_type'			=> 'recent',
		'recent_count'					=> 5,

		// Gallery
		'gallery_section_enable'		=> true,
		'gallery_title'					=> esc_html__( 'Gallery Posts', 'mega-blog-pro' ),
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 3,
		'gallery_alignment'				=> 'left-align',

		// Popular
		'popular_section_enable'		=> true,
		'popular_title'					=> esc_html__( 'Popular Posts', 'mega-blog-pro' ),
		'popular_content_type'			=> 'recent',
		'popular_column'				=> 'col-4',
		'popular_count'					=> 4,

		// Contact
		'contact_section_enable'		=> true,
		'contact_title'					=> esc_html__( 'Get In Touch', 'mega-blog-pro' ),
		'contact_address_title'			=> esc_html__( 'Address &#58;', 'mega-blog-pro' ),
		'contact_address'				=> esc_html__( '265 Street, Manbhawan, Lalitpur, Nepal', 'mega-blog-pro' ),
		'contact_phone_title'			=> esc_html__( 'Call Us &#58;', 'mega-blog-pro' ),
		'contact_phone'					=> esc_html__( '+00 0000000000', 'mega-blog-pro' ),
		'contact_email_title'			=> esc_html__( 'Email &#58;', 'mega-blog-pro' ),
		'contact_email'					=> 'info@themepalace.com',

	);

	$output = apply_filters( 'mega_blog_pro_default_theme_options', $mega_blog_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}